
######
peltak
######

.. readme_inclusion_marker

**peltak** is a set of fabric commands to help out manage a project. 

Installation
============

.. code-block:: shell

    $ pip install peltak


Contributing
============

Setting up development repo
---------------------------

.. code-block:: shell

    $ git clone git@github.com:novopl/peltak.git
    $ cd peltak
    $ virtualenv env
    $ source ./env/bin/activate
    $ pip install -r requirements.txt -r ops/devrequirements.txt
